%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% NSERC Style File
%% (C) 2017 Herve Lombaert
%%
%% Unofficial NSERC style file
%%
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%%
%% herve.lombaert@gmail.com


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% LaTeX Style
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{nserc}[2017/07/01 NSERC style]

\LoadClass[12pt,letterpaper,onecolumn]{article}
\RequirePackage[T1]{fontenc}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Set page dimensions
%%%
\RequirePackage[headheight=15pt,headsep=10pt]{geometry}  %% Change page margins
\geometry{hmargin=.75in,vmargin=.75in} %% 3/4in permitted

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Header Spacing
%%%
\RequirePackage[explicit]{titlesec}
\setlength{\parindent}{0pt}
\setlength{\parskip}{0.25em}
\titlespacing*{\part}{0pt}{0.2em}{0.0em}
\titlespacing*{\section}{0pt}{0.2em}{0.0em}
\titlespacing*{\subsection}{0pt}{0.2em}{0em}
\titlespacing*{\subsubsection}{0pt}{0.2em}{0em}
\titlespacing*{\paragraph}{0pt}{0.2em}{0em}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Small caps headers
%%% 
\renewcommand\thepart{\arabic{part}}
\titleformat{\part}
  {\normalfont\LARGE\bfseries}
  {\thepart}
  {0.75em}{\textsc{#1}}
\titleformat{\section}
  {\normalfont\Large\bfseries}
  {\thesection}
  {.75em}{\textsc{#1}}
\titleformat{\subsection}
  {\normalfont\large\bfseries}
  {\thesubsection}
  {.75em}{\textsc{#1}}
\titleformat{\subsubsection}
  {\normalfont\normalsize\bfseries}
  {\thesubsubsection}
  {.75em}{\textsc{#1}}
\titleformat{\paragraph}[runin]
  {\normalfont\normalsize\bfseries}
  {\theparagraph}
  {.75em}{\textsc{#1}}
\titleformat{\subparagraph}[runin]
  {\normalfont\normalsize\bfseries}
  {\thesubparagraph}
  {.75em}{\textsc{#1}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Set headers and footers
%%%
\RequirePackage{fancyhdr}
\RequirePackage{xcolor}
\fancypagestyle{plain}{%
\fancyhf{}
\fancyhead{\normalfont\color{gray} Page \thepage \hfill \sc\@title \hfill \@author} % title/author in gray
\renewcommand{\footrulewidth}{0pt}
\renewcommand{\headrulewidth}{0.4pt}% position of header
}
\pagestyle{plain}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Define the IEEE citation control command
%%%

% Control bibliography style
% - force maximum nb of authors (et al.)
% - remove first name
%
% 1) Use bibliography style:
%
% \bstctlcite{IEEEexample:BSTcontrol}
% \bibliographystyle{IEEEtran}
% \bibliography{CRC-Lombaert}
%
% 2) Add this reference in bib file:
%
% @IEEEtranBSTCTL{IEEEexample:BSTcontrol,
%     CTLuse_article_number    = "yes",
%     CTLuse_paper             = "yes",
%     CTLuse_forced_etal       = "yes",
%     CTLmax_names_forced_etal = "2",
%     CTLnames_show_etal       = "1",
%     CTLdash_repeated_names   = "no",
%     CTLname_format_string    = "{}{vv~}{ll}{, jj}"
% };
%
\makeatletter
\def\bstctlcite#1{\@bsphack
\@for\@citeb:=#1\do{%
\edef\@citeb{\expandafter\@firstofone\@citeb}%
\if@filesw\immediate\write\@auxout{\string\citat
ion{\@citeb}}\fi}%
\@esphack}
\makeatother

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% End
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

